function vocal = separate()
% SEPARATE Summary of this function goes here
% Reference: Zafar Rafii and Bryan Pardo, "REpeating Pattern Extranction
% Technique (REPET): A Simple Method for Music/Voice Separation, IEEE, 2013
% Run this to separate the singing voice and the music
[x, fs] = audioread('test.wav');
len = 0.04;                             % Analysis window length in seconds
N = 2 .^ nextpow2(len * fs);			% Analysis window length in samples
window = hamming(N, 'periodic');		% Hamming window
step = N / 2;                           % Analysis step length (50% overlap)
[t, k] = size(x);                       % Number of samples and channels
if (k == 2)
    x = x(:, 1) + x(:, 2);              % Put two channels into one channels
end
k = 1;
X = stft(x(:, 1), window, step); 
V = abs(X(1 : N / 2 + 1, :, :));        % Discarding symmetric part
VSquare = mean(V .^ 2, 3);
b = beatSpectrum(V);
b(1) = [];                              % Discard lag 0
up = min(8, (length(x) / fs) / 3);
range = [0.8, up];
range = ceil(range * fs / step);
b = b(range(1) : range(2));
[~, p] = max(b);                        % Find the index of peak
p = p + range(1) - 1;
y = zeros(t, k);                        % Background music
vocal = zeros(t, k); 
Mask = mask(V(:, :, 1), p);
Mask = cat(1, Mask, flipud(Mask(1 : end - 2, :)));
yPart = istft(Mask .* X(:, :, 1), window, step);
y(:, 1) = yPart(1 : t);
vocal = x - y;                          % Vocal signal
end

